@@ -1,19 +1,13 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from decimal import Decimal
-from sql import Cast, Literal, Select, CombiningQuery, As
+from sql import Cast, Literal, Select, CombiningQuery
 
 from trytond import backend
+
 from .float import Float
 
 
-class SQLite_Cast(Cast):
-
-    def as_(self, output_name):
-        # Use PARSE_COLNAMES instead of CAST for final column
-        return As(self.expression, '%s [NUMERIC]' % output_name)
-
-
 class Numeric(Float):
     '''
     Define a numeric field (``decimal``).
@@ -22,18 +16,23 @@ class Numeric(Float):
     _sql_type = 'NUMERIC'
     _py_type = Decimal
 
-    def sql_column(self, table):
-        column = super(Numeric, self).sql_column(table)
-        db_type = backend.name
-        if db_type == 'sqlite':
+    def convert_order(self, name, tables, Model):
+        columns = super().convert_order(name, tables, Model)
+        if backend.name == 'sqlite':
+            # Must be cast because Decimal is stored as bytes
+            columns = [Cast(c, self.sql_type().base) for c in columns]
+        return columns
+
+    def _domain_column(self, operator, column):
+        column = super()._domain_column(operator, column)
+        if backend.name == 'sqlite':
             # Must be casted as Decimal is stored as bytes
-            column = SQLite_Cast(column, self.sql_type().base)
+            column = Cast(column, self.sql_type().base)
         return column
 
     def _domain_value(self, operator, value):
         value = super(Numeric, self)._domain_value(operator, value)
-        db_type = backend.name
-        if db_type == 'sqlite':
+        if backend.name == 'sqlite':
             if isinstance(value, (Select, CombiningQuery)):
                 return value
             # Must be casted as Decimal is adapted to bytes
