@@ -437,10 +437,10 @@ def load_modules(
                 Module.update_list()
 
     if not Transaction().connection:
-        with Transaction().start(database_name, 0):
+        with Transaction().start(database_name, 0, readonly=not update):
             _load_modules(update)
     else:
-        with Transaction().new_transaction(), \
+        with Transaction().new_transaction(readonly=not update), \
                 Transaction().set_user(0), \
                 Transaction().reset_context():
             _load_modules(update)
